@@ -44,6 +44,14 @@
 #include "magnifier.h" /* needed to access parent data */
 #include "magnifier-private.h" /* needed to access parent data */
 
+#undef DEBUG_CLIENT_CALLS
+
+#ifdef DEBUG_CLIENT_CALLS
+#define DBG(a) a
+#else
+#define DBG(a) 
+#endif
+
 static GObjectClass *parent_class = NULL;
 
 enum {
@@ -66,6 +74,29 @@ enum {
 	ZOOM_REGION_EXIT_MAGNIFIER
 } PropIdx;
 
+#ifdef DEBUG_CLIENT_CALLS
+gchar* prop_names[ZOOM_REGION_EXIT_MAGNIFIER + 1] = 
+{
+    "MANAGED",
+    "SMOOTHSCROLL",
+    "INVERT",
+    "SMOOTHING",
+    "CONTRAST",
+    "XSCALE",
+    "YSCALE",
+    "BORDERSIZE",
+    "BORDERCOLOR",
+    "XALIGN",
+    "YALIGN",
+    "VIEWPORT",
+    "TESTPATTERN",
+    "TIMING_TEST",
+    "TIMING_OUTPUT",
+    "TIMING_PAN_RATE",
+    "EXIT_MAGNIFIER"
+};
+#endif
+
 typedef enum {
 	ZOOM_REGION_ERROR_NONE,
 	ZOOM_REGION_ERROR_NO_TARGET_DRAWABLE,
@@ -1420,7 +1451,7 @@ zoom_region_moveto (ZoomRegion *zoom_region,
 {
 	long dx = x * zoom_region->xscale - zoom_region->priv->exposed_bounds.x1;
 	long dy = y * zoom_region->yscale - zoom_region->priv->exposed_bounds.y1;
-/*	fprintf (stderr, "moveto %ld %ld\n", x, y); */
+/* fprintf (stderr, "moveto %ld %ld\n", x, y); */
 
 	mag_timing.dx = 0;
 	mag_timing.dy = 0;
@@ -2062,7 +2093,7 @@ zoom_region_set_viewport (ZoomRegion *zoom_region,
 	zoom_region->viewport = *viewport;
 #define DEBUG
 #ifdef DEBUG
-	fprintf (stderr, "setting viewport %d,%d - %d,%d\n",
+	fprintf (stderr, "Setting viewport %d,%d - %d,%d\n",
 		 (int) viewport->x1, (int) viewport->y1,
 		 (int) viewport->x2, (int) viewport->y2);
 #endif
@@ -2097,7 +2128,9 @@ zoom_region_get_property (BonoboPropertyBag *bag,
 			  gpointer user_data)
 {
 	ZoomRegion *zoom_region = user_data;
-	
+
+	DBG (fprintf (stderr, "Get zoom-region property: %s\n", prop_names[arg_id]));
+
 	switch (arg_id) {
 	case ZOOM_REGION_MANAGED_PROP:
 		BONOBO_ARG_SET_BOOLEAN (arg, zoom_region->is_managed);
@@ -2170,6 +2203,8 @@ zoom_region_set_property (BonoboPropertyBag *bag,
 	ZoomRegion *zoom_region = user_data;
 	GNOME_Magnifier_RectBounds bounds;
 
+	DBG (fprintf (stderr, "Set zoom-region property: %s\n", prop_names[arg_id]));
+
 	switch (arg_id) {
 	case ZOOM_REGION_MANAGED_PROP:
 		zoom_region->is_managed = BONOBO_ARG_GET_BOOLEAN (arg);
@@ -2209,7 +2244,6 @@ zoom_region_set_property (BonoboPropertyBag *bag,
 		break;
 	case ZOOM_REGION_BORDERSIZE_PROP:
 		zoom_region->border_size = BONOBO_ARG_GET_LONG (arg);
-	    g_message ("border size set to %d", zoom_region->border_size);
 		zoom_region_recompute_exposed_viewport (zoom_region);
 		zoom_region_update_current (zoom_region);
 		break;
@@ -2362,13 +2396,17 @@ impl_zoom_region_set_roi (PortableServer_Servant servant,
 	ZoomRegion *zoom_region =
 		ZOOM_REGION (bonobo_object_from_servant (servant));
 
+	DBG (fprintf (stderr, "Set ROI: \t%d,%d %d,%d\n", 
+		      bounds->x1, bounds->y1, bounds->x2, bounds->y2));
+
 	/* if these bounds are clearly bogus, warn and ignore */
 	if (!bounds || (bounds->x2 <= bounds->x1)
 	    || (bounds->y2 < bounds->y1) || 
 	    ((bounds->x1 + bounds->x2)/2 < 0) || 
 	    ((bounds->y1 + bounds->y2)/2 < 0))
 	{
-	    g_warning ("Bad bounds request, ignoring.");
+	    g_warning ("Bad bounds request (%d,%d to %d,%d), ignoring.\n",
+		       bounds->x1, bounds->y1, bounds->x2, bounds->y2);
 	    return;
 	}
 
